#
# spec file for package python3-tornado
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-tornado
Version:        4.2.1
Release:        6.1
Url:            http://www.tornadoweb.org
Summary:        Open source version of scalable, non-blocking web server that power FriendFeed
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/t/tornado/tornado-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-certifi
BuildRequires:  python3-pycurl
BuildRequires:  python3-simplejson
# Not yet available for python 3
# BuildRequires:  python3-Twisted
Requires:       python3-certifi
Requires:       python3-simplejson
Recommends:     python3-pycurl
Recommends:     python3-Twisted
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif

%description
Tornado is an open source version of the scalable, non-blocking web server and
tools that power FriendFeed. The FriendFeed application is written using a web
framework that looks a bit like web.py or Google's webapp, but with additional
tools and optimizations to take advantage of the underlying non-blocking
infrastructure.

The framework is distinct from most mainstream web server frameworks (and
certainly most Python frameworks) because it is non-blocking and reasonably
fast. Because it is non-blocking and uses epoll, it can handle thousands of
simultaneous standing connections, which means it is ideal for real-time web
services. We built the web server specifically to handle FriendFeed's real-time
features — every active user of FriendFeed maintains an open connection to the
FriendFeed servers. (For more information on scaling servers to support
thousands of clients, see The C10K problem.)

%prep
%setup -q -n tornado-%{version}
# Fix non-executable script rpmlint issue:
find demos tornado -name "*.py" -exec sed -i "/#\!\/usr\/bin\/.*/d" {} \;

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%if 0%{?suse_version}
%fdupes demos
%endif

%files
%defattr(-,root,root,-)
%doc demos
%{python3_sitearch}/tornado
%{python3_sitearch}/tornado-%{version}-py%{py3_ver}.egg-info

%changelog
* Sat Sep 26 2015 toddrme2178@gmail.com
- BuildRequires python3-certifi since it is required by tests.
  It is already in Requires.
* Sat Jul 18 2015 arun@gmx.de
- update to version 4.2.1:
  * This release fixes a path traversal vulnerability in
    StaticFileHandler, in which files whose names started with the
    static_path directory but were not actually in that directory
    could be accessed.
* Sat May 30 2015 arun@gmx.de
- update to version 4.2:
  * Backwards-compatibility notes
  - "SSLIOStream.connect" and .IOStream.start_tls now validate
    certificates by default.
  - Certificate validation will now use the system CA root
    certificates instead of "certifi" when possible (i.e. Python
    2.7.9+ or 3.4+). This includes .IOStream and
    "simple_httpclient", but not "curl_httpclient".
  - The default SSL configuration has become stricter, using
    ssl.create_default_context where available on the client side.
    (On the server side, applications are encouraged to migrate from
    the "ssl_options" dict-based API to pass an ssl.SSLContext
    instead).
  - The deprecated classes in the tornado.auth module,
    "GoogleMixin", "FacebookMixin", and "FriendFeedMixin" have been
    removed.
  * New modules: tornado.locks and tornado.queues
  - These modules provide classes for coordinating coroutines,
    merged from Toro http://toro.readthedocs.org
    (See http://www.tornadoweb.org/en/stable/releases/v4.2.0.html for more details)
  * tornado.autoreload
  - Improved compatibility with Windows.
  - Fixed a bug in Python 3 if a module was imported during a reload
    check.
  * tornado.concurrent
  - .run_on_executor now accepts arguments to control which
    attributes it uses to find the .IOLoop and executor.
  * tornado.curl_httpclient
  - Fixed a bug that would cause the client to stop processing
    requests if an exception occurred in certain places while there
    is a queue.
  * tornado.escape
  - .xhtml_escape now supports numeric character references in hex
    format ("&#x20;")
  * tornado.gen
  - .WaitIterator no longer uses weak references, which fixes
    several garbage-collection-related bugs.
  - tornado.gen.Multi and tornado.gen.multi_future (which are used
    when yielding a list or dict in a coroutine) now log any
    exceptions after the first if more than one .Future fails
    (previously they would be logged when the .Future was
    garbage-collected, but this is more reliable).  Both have a new
    keyword argument "quiet_exceptions" to suppress logging of
    certain exception types; to use this argument you must call
    "Multi" or "multi_future" directly instead of simply yielding a
    list.
  - .multi_future now works when given multiple copies of the same
    .Future.
  - On Python 3, catching an exception in a coroutine no longer
    leads to leaks via "Exception.__context__".
  * tornado.httpclient
  - The "raise_error" argument now works correctly with the
    synchronous .HTTPClient.
  - The synchronous .HTTPClient no longer interferes with
    .IOLoop.current().
  * tornado.httpserver
  - .HTTPServer is now a subclass of tornado.util.Configurable.
  * tornado.httputil
  - .HTTPHeaders can now be copied with copy.copy and copy.deepcopy.
  * tornado.ioloop
  - The .IOLoop constructor now has a "make_current" keyword
    argument to control whether the new .IOLoop becomes
    .IOLoop.current().
  - Third-party implementations of .IOLoop should accept "**kwargs"
    in their ~.IOLoop.initialize methods and pass them to the
    superclass implementation.
  - .PeriodicCallback is now more efficient when the clock jumps
    forward by a large amount.
  * tornado.iostream
  - "SSLIOStream.connect" and .IOStream.start_tls now validate
    certificates by default.
  - New method .SSLIOStream.wait_for_handshake allows server-side
    applications to wait for the handshake to complete in order to
    verify client certificates or use NPN/ALPN.
  - The .Future returned by "SSLIOStream.connect" now resolves after
    the handshake is complete instead of as soon as the TCP
    connection is established.
  - Reduced logging of SSL errors.
  - .BaseIOStream.read_until_close now works correctly when a
    "streaming_callback" is given but "callback" is None (i.e. when
    it returns a .Future)
  * tornado.locale
  - New method .GettextLocale.pgettext allows additional context to be
    supplied for gettext translations.
  * tornado.log
  - .define_logging_options now works correctly when given a
    non-default "options" object.
  * tornado.process
  - New method .Subprocess.wait_for_exit is a coroutine-friendly
    version of .Subprocess.set_exit_callback.
  * tornado.simple_httpclient
  - Improved performance on Python 3 by reusing a single
    ssl.SSLContext.
  - New constructor argument "max_body_size" controls the maximum
    response size the client is willing to accept. It may be bigger
    than "max_buffer_size" if "streaming_callback" is used.
  * tornado.tcpserver
  - .TCPServer.handle_stream may be a coroutine (so that any
    exceptions it raises will be logged).
  * tornado.util
  - .import_object now supports unicode strings on Python 2.
  - .Configurable.initialize now supports positional arguments.
  * tornado.web
  - Key versioning support for cookie signing. "cookie_secret"
    application setting can now contain a dict of valid keys with
    version as key. The current signing key then must be specified
    via "key_version" setting.
  - Parsing of the "If-None-Match" header now follows the RFC and
    supports weak validators.
  - Passing "secure=False" or "httponly=False" to
    .RequestHandler.set_cookie now works as expected (previously
    only the presence of the argument was considered and its value
    was ignored).
  - .RequestHandler.get_arguments now requires that its " argument
    be of type bool. This helps prevent errors caused by the
    slightly dissimilar interfaces between the singular and plural
    methods.
  - Errors raised in "_handle_request_exception" are now logged more
    reliably.
  - .RequestHandler.redirect now works correctly when called from a
    handler whose path begins with two slashes.
  - Passing messages containing "%%" characters to
    tornado.web.HTTPError no longer causes broken error messages.
  * tornado.websocket
  - The "on_close" method will no longer be called more than once.
  - When the other side closes a connection, we now echo the
    received close code back instead of sending an empty close
    frame.
* Mon Feb  9 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.1:
  * Highlights
    + If a Future contains an exception but that exception is never
    examined or re-raised (e.g. by yielding the Future), a stack
    trace will be logged when the Future is garbage-collected.
    + New class tornado.gen.WaitIterator provides a way to iterate
    over Futures in the order they resolve.
    + The tornado.websocket module now supports compression via the
    “permessage-deflate” extension. Override
    WebSocketHandler.get_compression_options to enable on the server
    side, and use the compression_options keyword argument to
    websocket_connect on the client side.
    + When the appropriate packages are installed, it is possible to
    yield asyncio.Future or Twisted Defered objects in Tornado
    coroutines.
  * Backwards-compatibility notes
    + HTTPServer now calls start_request with the correct
    arguments. This change is backwards-incompatible, afffecting any
    application which implemented HTTPServerConnectionDelegate by
    following the example of Application instead of the documented
    method signatures.
  * tornado.concurrent
    + If a Future contains an exception but that exception is never
    examined or re-raised (e.g. by yielding the Future), a stack
    trace will be logged when the Future is garbage-collected.
    + Future now catches and logs exceptions in its callbacks.
  * tornado.curl_httpclient
    + tornado.curl_httpclient now supports request bodies for PATCH
    and custom methods.
    + tornado.curl_httpclient now supports resubmitting bodies after
    following redirects for methods other than POST.
    + curl_httpclient now runs the streaming and header callbacks on
    the IOLoop.
    + tornado.curl_httpclient now uses its own logger for debug output
    so it can be filtered more easily.
  * tornado.gen
    + New class tornado.gen.WaitIterator provides a way to iterate
    over Futures in the order they resolve.
    + When the singledispatch library is available (standard on Python
    3.4, available via pip install singledispatch on older
    versions), the convert_yielded function can be used to make
    other kinds of objects yieldable in coroutines.
    + New function tornado.gen.sleep is a coroutine-friendly analogue
    to time.sleep.
    + gen.engine now correctly captures the stack context for its
    callbacks.
  * tornado.httpclient
    + tornado.httpclient.HTTPRequest accepts a new argument
    raise_error=False to suppress the default behavior of raising an
    error for non-200 response codes.
  * tornado.httpserver
    + HTTPServer now calls start_request with the correct
    arguments. This change is backwards-incompatible, afffecting any
    application which implemented HTTPServerConnectionDelegate by
    following the example of Application instead of the documented
    method signatures.
    + HTTPServer now tolerates extra newlines which are sometimes
    inserted between requests on keep-alive connections.
    + HTTPServer can now use keep-alive connections after a request
    with a chunked body.
    + HTTPServer now always reports HTTP/1.1 instead of echoing the
    request version.
  * tornado.httputil
    + New function tornado.httputil.split_host_and_port for parsing
    the netloc portion of URLs.
    + The context argument to HTTPServerRequest is now optional, and
    if a context is supplied the remote_ip attribute is also
    optional.
    + HTTPServerRequest.body is now always a byte string (previously
    the default empty body would be a unicode string on python 3).
    + Header parsing now works correctly when newline-like unicode
    characters are present.
    + Header parsing again supports both CRLF and bare LF line
    separators.
    + Malformed multipart/form-data bodies will always be logged
    quietly instead of raising an unhandled exception; previously
    the behavior was inconsistent depending on the exact error.
  * tornado.ioloop
    + The kqueue and select IOLoop implementations now report
    writeability correctly, fixing flow control in IOStream.
    + When a new IOLoop is created, it automatically becomes “current”
    for the thread if there is not already a current instance.
    + New method PeriodicCallback.is_running can be used to see
    whether the PeriodicCallback has been started.
  * tornado.iostream
    + IOStream.start_tls now uses the server_hostname parameter for
    certificate validation.
    + SSLIOStream will no longer consume 100%% CPU after certain error
    conditions.
    + SSLIOStream no longer logs EBADF errors during the handshake as
    they can result from nmap scans in certain modes.
  * tornado.options
    + parse_config_file now always decodes the config file as utf8 on
    Python 3.
    + tornado.options.define more accurately finds the module defining
    the option.
  * tornado.platform.asyncio
    + It is now possible to yield asyncio.Future objects in coroutines
    when the singledispatch library is available and
    tornado.platform.asyncio has been imported.
    + New methods tornado.platform.asyncio.to_tornado_future and
    to_asyncio_future convert between the two libraries’ Future
    classes.
  * tornado.platform.twisted
    + It is now possible to yield Deferred objects in coroutines when
    the singledispatch library is available and
    tornado.platform.twisted has been imported.
  * tornado.tcpclient
    + TCPClient will no longer raise an exception due to an ill-timed
    timeout.
  * tornado.tcpserver
    + TCPServer no longer ignores its read_chunk_size argument.
  * tornado.testing
    + AsyncTestCase has better support for multiple
    exceptions. Previously it would silently swallow all but the
    last; now it raises the first and logs all the rest.
    + AsyncTestCase now cleans up Subprocess state on tearDown when
    necessary.
  * tornado.web
    + The asynchronous decorator now understands
    concurrent.futures.Future in addition to
    tornado.concurrent.Future.
    + StaticFileHandler no longer logs a stack trace if the connection
    is closed while sending the file.
    + RequestHandler.send_error now supports a reason keyword
    argument, similar to tornado.web.HTTPError.
    + RequestHandler.locale now has a property setter.
    + Application.add_handlers hostname matching now works correctly
    with IPv6 literals.
    + Redirects for the Application default_host setting now match the
    request protocol instead of redirecting HTTPS to HTTP.
    + Malformed _xsrf cookies are now ignored instead of causing
    uncaught exceptions.
    + Application.start_request now has the same signature as
    HTTPServerConnectionDelegate.start_request.
  * tornado.websocket
    + The tornado.websocket module now supports compression via the
    “permessage-deflate” extension. Override
    WebSocketHandler.get_compression_options to enable on the server
    side, and use the compression_options keyword argument to
    websocket_connect on the client side.
    + WebSocketHandler no longer logs stack traces when the connection
    is closed.
    + WebSocketHandler.open now accepts *args, **kw for consistency
    with RequestHandler.get and related methods.
    + The Sec-WebSocket-Version header now includes all supported
    versions.
    + websocket_connect now has a on_message_callback keyword argument
    for callback-style use without read_message().
* Mon Dec  1 2014 andrea@opensuse.org
- added python3-certifi as dependency to fix boo #907716
- removed python3-pycares from recommends as the package doesn't exist
* Thu Oct  2 2014 toddrme2178@gmail.com
- Remove python-pycares BuildRequires since it is optional and
  not in openSUSE:Factory
* Wed Oct  1 2014 toddrme2178@gmail.com
- Update to version 4.0.2
  + Bug fixes
  * Fixed a bug that could sometimes cause a timeout to fire after being
    cancelled.
  * `.AsyncTestCase` once again passes along arguments to test methods,
    making it compatible with extensions such as Nose's test generators.
  * `.StaticFileHandler` can again compress its responses when gzip is enabled.
  * ``simple_httpclient`` passes its ``max_buffer_size`` argument to the
    underlying stream.
  * Fixed a reference cycle that can lead to increased memory consumption.
  * `.add_accept_handler` will now limit the number of times it will call
    `~socket.socket.accept` per `.IOLoop` iteration, addressing a potential
    starvation issue.
  * Improved error handling in `.IOStream.connect` (primarily for FreeBSD
    systems)
- Update to version 4.0.1
  + Bug fixes
  * The build will now fall back to pure-python mode if the C extension
    fails to build for any reason (previously it would fall back for some
    errors but not others).
  * `.IOLoop.call_at` and `.IOLoop.call_later` now always return
    a timeout handle for use with `.IOLoop.remove_timeout`.
  * If any callback of a `.PeriodicCallback` or `.IOStream` returns a
    `.Future`, any error raised in that future will now be logged
    (similar to the behavior of `.IOLoop.add_callback`).
  * Fixed an exception in client-side websocket connections when the
    connection is closed.
  * ``simple_httpclient`` once again correctly handles 204 status
    codes with no content-length header.
  * Fixed a regression in ``simple_httpclient`` that would result in
    timeouts for certain kinds of errors.
- Update to version 4.0.0
  + Highlights
  * The `tornado.web.stream_request_body` decorator allows large files to be
    uploaded with limited memory usage.
  * Coroutines are now faster and are used extensively throughout Tornado itself.
    More methods now return `Futures <.Future>`, including most `.IOStream`
    methods and `.RequestHandler.flush`.
  * Many user-overridden methods are now allowed to return a `.Future`
    for flow control.
  * HTTP-related code is now shared between the `tornado.httpserver`,
    ``tornado.simple_httpclient`` and `tornado.wsgi` modules, making support
    for features such as chunked and gzip encoding more consistent.
    `.HTTPServer` now uses new delegate interfaces defined in `tornado.httputil`
    in addition to its old single-callback interface.
  * New module `tornado.tcpclient` creates TCP connections with non-blocking
    DNS, SSL handshaking, and support for IPv6.
  + See more release details at
    http://www.tornadoweb.org/en/stable/releases/v4.0.0.html
- Update to version 3.2.2
  + Security fixes
  * The XSRF token is now encoded with a random mask on each request.
    This makes it safe to include in compressed pages without being
    vulnerable to the `BREACH attack <http://breachattack.com>`_.
    This applies to most applications that use both the ``xsrf_cookies``
    and ``gzip`` options (or have gzip applied by a proxy).
  + Backwards-compatibility notes
  * If Tornado 3.2.2 is run at the same time as older versions on the same
    domain, there is some potential for issues with the differing cookie
    versions.  The `.Application` setting ``xsrf_cookie_version=1`` can
    be used for a transitional period to generate the older cookie format
    on newer servers.
  + Other changes
  * ``tornado.platform.asyncio`` is now compatible with ``trollius`` version 0.3.
* Sun May 11 2014 andrea@opensuse.org
- new upstream version 3.2.1
  - several new modules and bugfixes check website for details
    http://www.tornadoweb.org/en/stable/releases.html
* Sun Dec 22 2013 ocefpaf@gmail.com
- Update to 3.1.1:
  - StaticFileHandler no longer fails if the client requests a Range that is
    larger than the entire file (Facebook has a crawler that does this).
  - RequestHandler.on_connection_close now works correctly on subsequent
    requests of a keep-alive connection.
- Replace python3-distribute with python3-setuptools requirements
- Use download Url as source
- Remove depreciated python(abi) requirement
* Thu Apr 11 2013 alexandre@exatati.com.br
- Update to 3.0.1:
  - The interface of tornado.auth.FacebookGraphMixin is now
    consistent with its documentation and the rest of the module.
    The get_authenticated_user and facebook_request methods return
    a Future and the callback argument is optional.
  - The tornado.testing.gen_test decorator will no longer be
    recognized as a (broken) test by nose.
  - Work around a bug in Ubuntu 13.04 betas involving an
    incomplete backport of the ssl.match_hostname function.
  - tornado.websocket.websocket_connect now fails cleanly when it
    attempts to connect to a non-websocket url.
  - tornado.testing.LogTrapTestCase once again works with byte
    strings on Python 2.
  - The request attribute of tornado.httpclient.HTTPResponse is
    now always an HTTPRequest, never a _RequestProxy.
  - Exceptions raised by the tornado.gen module now have better
    messages when tuples are used as callback keys.
* Sat Mar 30 2013 alexandre@exatati.com.br
- Update to 3.0:
  - Please read full changelog at
    http://www.tornadoweb.org/en/stable/releases/v3.0.0.html
* Sun Nov 25 2012 alexandre@exatati.com.br
- Update to 2.4.1:
  - Fixed a memory leak in tornado.stack_context that was especially
    likely with long-running @gen.engine functions.
  - tornado.auth.TwitterMixin now works on Python 3.
  - Fixed a bug in which IOStream.read_until_close with a streaming
    callback would sometimes pass the last chunk of data to the
    final callback instead of the streaming callback.
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Thu Sep  6 2012 toddrme2178@gmail.com
- Restore BuildRequires: python3  This package depends on hash
  algorithms that are only available if python3 is installed,
  python3-devel will not pull them in.  Building will fail if
  BuildRequires: python3 is removed.
* Wed Sep  5 2012 alexandre@exatati.com.br
- Update to 2.4:
  - Please check changelog at
    http://www.tornadoweb.org/documentation/releases/v2.4.0.html
* Fri Jun  1 2012 alexandre@exatati.com.br
- Update to 2.3:
  - Please check changelog at
    http://www.tornadoweb.org/documentation/releases/v2.3.0.html
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
- Improve openSUSE 11.4 build fix
- Clean up spec file
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
- Removed test for unsupported openSUSE versions
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- python3 package created
